package App::CPANMetaUtils;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-08-26'; # DATE
our $DIST = 'App-CPANMetaUtils'; # DIST
our $VERSION = '0.010'; # VERSION

1;
# ABSTRACT: CLI utilities related to CPAN Meta

__END__

=pod

=encoding UTF-8

=head1 NAME

App::CPANMetaUtils - CLI utilities related to CPAN Meta

=head1 VERSION

This document describes version 0.010 of App::CPANMetaUtils (from Perl distribution App-CPANMetaUtils), released on 2020-08-26.

=head1 DESCRIPTION

This distribution contains CLI utilities related to CPAN Meta:

=over

=item * L<convert-cpan-meta>

=item * L<gen-cpan-meta>

=item * L<validate-cpan-meta>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-CPANMetaUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-CPANMetaUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CPANMetaUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<CPAN::Meta>, L<CPAN::Meta::Validator>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
